@@ -4,7 +4,7 @@
 # This file is part of the Metasploit Framework and may be subject to
 # redistribution and commercial restrictions. Please see the Metasploit
 # Framework web site for more information on licensing and terms of use.
-# http://metasploit.com/framework/
+# https://metasploit.com/framework/
 ##
 
 
@@ -34,7 +34,15 @@ module CommandShellOptions
     if self.platform and self.platform.kind_of? Msf::Module::Platform
       session.platform = self.platform.realname.downcase
     end
-    session.arch     = self.arch if self.arch
+
+    if self.arch
+      if self.arch.kind_of?(Array)
+        session.arch = self.arch.join('')
+      else
+        session.arch = self.arch
+      end
+    end
+
   end
 
 end
