@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = ExcellentRanking
 
@@ -64,7 +62,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'DefaultOptions' =>
         {
           'EXITFUNC' => 'seh',
-          'InitialAutoRunScript' => 'migrate -f'
+          'InitialAutoRunScript' => 'post/windows/manage/priv_migrate'
         },
       'Payload'        =>
         {
@@ -471,5 +469,4 @@ exec sp_executesql @z|
 
     return nil
   end
-
 end
